
# q-expansion of newform 1100.6.b.c, downloaded from the LMFDB on 26 December 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1100
weight = 6
poly_data = [64, 0, -15, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0], 1], [[0, -7, 0, 1], 8], [[0, 23, 0, -1], 2], [[-60, 0, 8, 0], 1]]

hecke_ring_character_values = [[551, [1, 0, 0, 0]], [177, [-1, 0, 0, 0]], [101, [1, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0], [0, -3, 0, 1], [0, 0, 0, 0], [0, -134, 0, 3], [-121, 0, 0, 0], [0, 616, 0, -5], [0, 62, 0, -47], [-972, 0, 31, 0], [0, 1673, 0, -59], [3288, 0, 78, 0], [1249, 0, -371, 0], [0, 7337, 0, -94], [-3252, 0, -477, 0], [0, 5814, 0, 644], [0, -18408, 0, 522], [0, -1646, 0, -1150], [-6063, 0, -585, 0], [36564, 0, -562, 0], [0, -14667, 0, -1733], [-23061, 0, -951, 0], [0, 4120, 0, 799], [7390, 0, 852, 0], [0, -37282, 0, 802], [16849, 0, 650, 0], [0, -63081, 0, -3188], [-102770, 0, -2593, 0], [0, -43184, 0, 3118], [0, -9242, 0, -9721], [-80386, 0, 656, 0], [0, 151993, 0, 3038], [0, -126844, 0, -4195], [36998, 0, -14201, 0], [0, 147695, 0, -2126], [-270050, 0, 1239, 0], [-20794, 0, 547, 0], [379614, 0, 2414, 0], [0, 13555, 0, -15690], [0, 110940, 0, -21856], [0, 427176, 0, -2121], [0, -178526, 0, -10204], [-241963, 0, 16753, 0], [-312525, 0, -18592, 0], [282975, 0, 10851, 0], [0, 18564, 0, 22724], [0, -45878, 0, -19732], [-286088, 0, -26100, 0], [135380, 0, 27720, 0], [0, -149723, 0, -17225], [0, -947658, 0, 6963], [746317, 0, 35604, 0], [0, 299072, 0, -31274], [520562, 0, -39542, 0], [-298896, 0, 54506, 0], [208195, 0, 7589, 0], [0, -480310, 0, -6218], [0, -1116138, 0, -16371], [-285082, 0, -15068, 0], [118472, 0, -14763, 0], [0, 441730, 0, 36150], [1055062, 0, 20090, 0], [0, -811788, 0, 12206], [0, -908764, 0, -23519], [0, 667260, 0, 33379], [1066340, 0, -8582, 0], [0, -160825, 0, 51966], [0, -2409417, 0, 6786], [-83395, 0, 12207, 0], [0, 1449122, 0, -751], [0, 2392328, 0, 11125], [3256790, 0, 5849, 0], [0, 157251, 0, -9498], [2246688, 0, -5313, 0], [0, -1583273, 0, 18123], [0, -1102878, 0, -54013], [-723737, 0, -20313, 0], [0, -2702855, 0, 29087], [-679413, 0, -101100, 0], [0, -558678, 0, -157322], [1509914, 0, 89386, 0], [-2970882, 0, -7640, 0], [2510796, 0, -93162, 0], [737390, 0, -130830, 0], [1557822, 0, -105321, 0], [0, -2779411, 0, 167760], [-4513680, 0, -89762, 0], [0, 607463, 0, -21671], [5053637, 0, 135370, 0], [0, 442788, 0, -327710], [4888756, 0, -31606, 0], [0, 826243, 0, 72865], [0, -2439135, 0, -25017], [568896, 0, -306411, 0], [0, -2801585, 0, -235611], [-4753592, 0, -238396, 0], [-7414028, 0, 38988, 0], [0, 1903138, 0, -11452], [5313845, 0, -118796, 0], [-1594203, 0, 101544, 0], [0, 4583012, 0, -145401], [1231716, 0, 2717, 0], [0, -7671728, 0, -120810], [0, 50862, 0, -338961], [0, -1847836, 0, -301070], [-8652056, 0, -169966, 0], [-4674948, 0, -238972, 0], [0, -2341433, 0, 176934], [0, 10044852, 0, -191190], [0, 9085980, 0, -93384], [3935376, 0, 76896, 0], [5630622, 0, -309319, 0], [0, 3855378, 0, 613492], [0, -2045072, 0, 376396], [0, 5736350, 0, 174988], [-5417405, 0, -234933, 0], [-5484639, 0, 44429, 0], [-142713, 0, -215052, 0], [0, -6366217, 0, 291351], [0, -11904583, 0, 188845], [0, 3616803, 0, -49620], [5093754, 0, -44448, 0], [6620065, 0, 251608, 0], [0, -1341058, 0, -511104], [0, -14912618, 0, -163405], [0, -9519336, 0, -304254], [-6052589, 0, 319627, 0], [-1027026, 0, -838929, 0], [20275973, 0, 199076, 0], [-4093953, 0, 313677, 0], [0, 4895531, 0, -216247], [0, 3688244, 0, 55278], [-2871398, 0, -28902, 0], [0, 13480988, 0, 147916], [-1160257, 0, -341907, 0], [0, 19116406, 0, 201684], [-9146856, 0, 818493, 0], [-584472, 0, -560243, 0], [0, 7287498, 0, 852396], [0, -419784, 0, 92878], [0, -706521, 0, 1310328], [420172, 0, -1153987, 0], [-5202250, 0, -1218768, 0], [-5911570, 0, -479060, 0], [0, 7146329, 0, 42747], [0, 9016184, 0, -230747], [13490859, 0, 71290, 0], [-21459453, 0, 745473, 0], [0, -16481738, 0, -1140236], [0, -30285064, 0, -289460], [9317349, 0, 96949, 0], [0, 29300272, 0, 265364], [0, 30068432, 0, -534625], [-26179795, 0, -836078, 0], [0, -16410492, 0, 564362], [0, 30416034, 0, -516996], [0, 12761892, 0, 223048], [1594548, 0, 1011246, 0], [3178258, 0, 421704, 0], [-32369610, 0, -618102, 0], [0, -34031532, 0, 840565], [-2722614, 0, -1774254, 0], [0, -6942159, 0, 1353813], [0, -21079770, 0, -147897], [0, 7349592, 0, -256094], [-18564363, 0, -1434993, 0], [0, 11940539, 0, -2090186], [0, 28133793, 0, 88923], [13519664, 0, -1768380, 0], [0, -6060234, 0, -2174789], [11172738, 0, -1860854, 0], [0, -55056077, 0, -116968], [2279870, 0, 649834, 0], [19937894, 0, -304908, 0], [-25895964, 0, -1636185, 0], [0, 14100356, 0, 1108263], [5577533, 0, 666911, 0], [50215231, 0, 479864, 0], [-43295902, 0, -523497, 0], [-255561, 0, 1541142, 0], [0, 26031124, 0, -1424816], [21882580, 0, -2027976, 0], [0, 53821440, 0, -191948], [38175954, 0, 1126890, 0], [0, 14679265, 0, -840686], [0, -38768334, 0, -472446], [0, -40081677, 0, 206937], [-4088218, 0, 452662, 0], [0, 13114972, 0, -1554975], [0, 5678464, 0, 3003994], [-34243678, 0, -1434085, 0], [-50926162, 0, 194302, 0], [0, 24437873, 0, -1455618], [0, 57342810, 0, -854511], [-28342049, 0, 1886461, 0], [3576030, 0, 631620, 0], [0, -36545320, 0, -1870049], [0, -58552733, 0, -1003222], [44654566, 0, 1712623, 0], [0, 24162971, 0, -1387020], [0, 11256834, 0, -2117538], [0, -33739650, 0, 1684539], [-19636112, 0, -2500279, 0], [29032698, 0, 2447960, 0], [0, 55141374, 0, 429916], [49434752, 0, -995122, 0], [-31588125, 0, 1458669, 0], [0, 14461643, 0, 951010], [-90189095, 0, 733743, 0], [0, -64474324, 0, -715322], [20359032, 0, 3250422, 0], [-18513040, 0, -1581918, 0], [0, 12039200, 0, 2543696], [-24833289, 0, -1560606, 0], [0, -46197879, 0, -795367], [0, 38421924, 0, -2535966], [-52058658, 0, 800799, 0], [-32024833, 0, -1645332, 0], [0, 25921200, 0, 1585093], [49972196, 0, 1451386, 0], [0, -61113512, 0, 407006], [0, 14397419, 0, 94480], [31684632, 0, -2168515, 0], [14034816, 0, 1135927, 0], [111038119, 0, -14860, 0], [0, -8588517, 0, -2597497], [0, -85930456, 0, 186595], [2065958, 0, 4136702, 0], [0, 10362374, 0, -729524], [-7965216, 0, -3192450, 0], [0, 92166744, 0, -2121767], [65996184, 0, -462867, 0], [0, 41134877, 0, -3695778], [-15420408, 0, -2615075, 0], [-59886286, 0, -1956276, 0], [-37770424, 0, -1342694, 0], [0, -121535797, 0, 641583], [0, -39730806, 0, 2168358], [62007631, 0, -1923066, 0], [0, 58024128, 0, 1849647], [72716427, 0, -1144689, 0], [24668003, 0, 2286043, 0], [0, -53862267, 0, 3648003], [5138432, 0, 6628908, 0], [0, -100681836, 0, 1683326], [39305299, 0, 1270662, 0], [0, -78867464, 0, -479488], [99797756, 0, -742622, 0], [0, 79982588, 0, 1873166], [-58390132, 0, -5133104, 0], [-59543414, 0, -912870, 0], [0, 93626662, 0, 1212836], [0, -34272960, 0, 3629032], [3752238, 0, -1670451, 0], [0, 121439185, 0, 631343], [-96269662, 0, 378866, 0], [0, -147411794, 0, -491563], [-8219148, 0, -3354162, 0], [1213670, 0, 638172, 0], [0, 93566658, 0, 164899], [0, -80027589, 0, 751806], [0, -111983338, 0, 2388575], [0, 67742820, 0, 59486], [0, -28412220, 0, -8086293], [105577034, 0, -3358537, 0], [0, -8104154, 0, 361555], [0, 49044018, 0, -5983626], [-90466400, 0, -6446022, 0], [-71482607, 0, 4295114, 0], [165070893, 0, -1731252, 0], [0, 219364078, 0, -67436], [0, 3273802, 0, 8918870], [-208691563, 0, 1296552, 0], [0, 6909755, 0, 749477], [0, 150415386, 0, -2049838], [-132906876, 0, 3925321, 0], [0, -51036180, 0, 8856067], [0, 113672285, 0, -2314839], [0, 7451443, 0, -5408125], [99745126, 0, 7091790, 0], [12459360, 0, -2720923, 0], [-27410768, 0, -6463747, 0], [0, -60947580, 0, 61653], [36100779, 0, 7706471, 0], [0, -31475520, 0, 11290827], [22407470, 0, -4601370, 0], [0, -49626364, 0, -1436902], [-128216301, 0, -1748019, 0], [0, 65731818, 0, 2659772], [0, 13895754, 0, -1937649], [-61233331, 0, -1422481, 0], [183330574, 0, -2020993, 0], [236881705, 0, -2734390, 0], [0, 6848964, 0, -4454646], [0, 96564204, 0, -6713820], [55204446, 0, -11021511, 0], [0, -25370478, 0, 4934687], [19218524, 0, 1410331, 0], [-151025457, 0, 3785405, 0], [0, -29261981, 0, 8575802], [-66383502, 0, 2757315, 0], [0, -9640646, 0, -4590948], [0, 7722242, 0, -2122881], [0, -106129532, 0, -2037979], [-76355580, 0, -7767650, 0]]
